# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/survey/benchmark/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/survey/benchmark/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Survey\\Benchmark\\": "packages/survey/benchmark/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Survey\Benchmark\Providers\BenchmarkServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Benchmark'  => Survey\Benchmark\Facades\Benchmark::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Survey\\BenchmarkTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Survey\Benchmark\Providers\BenchmarkServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Survey\Benchmark\Providers\BenchmarkServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Survey\Benchmark\Providers\BenchmarkServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/benchmark/{modulename}

**User**

    http://path-to-route-folder/user/benchmark/{modulename}

**Public**

    http://path-to-route-folder/benchmarks


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/benchmark/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/benchmark/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/benchmark/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/benchmark/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/benchmark/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/benchmark/{modulename}/{slug}
    METHOD: GET