<?php

namespace Survey\Benchmark\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Survey\Benchmark\Http\Requests\BenchmarkRequest;
use Survey\Benchmark\Interfaces\BenchmarkRepositoryInterface;
use Survey\Benchmark\Models\Benchmark;
use Survey\Benchmark\Forms\Benchmark as Form;

/**
 * APIController  class for benchmark.
 */
class BenchmarkAPIController extends BaseController
{

    /**
     * Initialize benchmark resource controller.
     *
     * @param type BenchmarkRepositoryInterface $benchmark
     *
     * @return null
     */
    public function __construct(BenchmarkRepositoryInterface $benchmark)
    {
        parent::__construct();
        $this->repository = $benchmark;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Survey\Benchmark\Repositories\Criteria\BenchmarkResourceCriteria::class);
    }

    /**
     * Display a list of benchmark.
     *
     * @return Response
     */
    public function index(BenchmarkRequest $request)
    {
        return $this->repository
            ->setPresenter(\Survey\Benchmark\Repositories\Presenter\BenchmarkPresenter::class)
            ->paginate();
    }

    /**
     * Display benchmark.
     *
     * @param Request $request
     * @param Model   $benchmark
     *
     * @return Response
     */
    public function show(BenchmarkRequest $request, Benchmark $benchmark)
    {
        return $benchmark->setPresenter(\Survey\Benchmark\Repositories\Presenter\BenchmarkListPresenter::class);
        ;
    }

    /**
     * Create new benchmark.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(BenchmarkRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('benchmark::benchmark.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('benchmark/benchmark/' . $benchmark->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('benchmark/benchmark');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the benchmark.
     *
     * @param Request $request
     * @param Model   $benchmark
     *
     * @return Response
     */
    public function update(BenchmarkRequest $request, Benchmark $benchmark)
    {
        try {
            $data = $request->all();

            $benchmark->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('benchmark::benchmark.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('benchmark/benchmark/' . $benchmark->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('benchmark/benchmark/' . $benchmark->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the benchmark.
     *
     * @param Model   $benchmark
     *
     * @return Response
     */
    public function destroy(BenchmarkRequest $request, Benchmark $benchmark)
    {
        try {
            $benchmark->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('benchmark::benchmark.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('benchmark/benchmark/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('benchmark/benchmark/' . $benchmark->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
