<?php

namespace Survey\Benchmark\Policies;

use Litepie\User\Contracts\UserPolicy;
use Survey\Benchmark\Models\Benchmark;

class BenchmarkPolicy
{

    /**
     * Determine if the given user can view the benchmark.
     *
     * @param UserPolicy $user
     * @param Benchmark $benchmark
     *
     * @return bool
     */
    public function view(UserPolicy $user, Benchmark $benchmark)
    {
        if ($user->canDo('benchmark.benchmark.view') && $user->isAdmin()) {
            return true;
        }

        return $benchmark->user_id == user_id() && $benchmark->user_type == user_type();
    }

    /**
     * Determine if the given user can create a benchmark.
     *
     * @param UserPolicy $user
     * @param Benchmark $benchmark
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('benchmark.benchmark.create');
    }

    /**
     * Determine if the given user can update the given benchmark.
     *
     * @param UserPolicy $user
     * @param Benchmark $benchmark
     *
     * @return bool
     */
    public function update(UserPolicy $user, Benchmark $benchmark)
    {
        if ($user->canDo('benchmark.benchmark.edit') && $user->isAdmin()) {
            return true;
        }

        return $benchmark->user_id == user_id() && $benchmark->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given benchmark.
     *
     * @param UserPolicy $user
     * @param Benchmark $benchmark
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Benchmark $benchmark)
    {
        return $benchmark->user_id == user_id() && $benchmark->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given benchmark.
     *
     * @param UserPolicy $user
     * @param Benchmark $benchmark
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Benchmark $benchmark)
    {
        if ($user->canDo('benchmark.benchmark.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given benchmark.
     *
     * @param UserPolicy $user
     * @param Benchmark $benchmark
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Benchmark $benchmark)
    {
        if ($user->canDo('benchmark.benchmark.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
